@@ -5,11 +5,14 @@
 cross2netgwas <- function(cross.obj)
 {
   nchr <- length(cross.obj$geno)
-  
   netgwas.obj <- cross.obj$geno[[1]]$data
-  for(i in 2: nchr ) {
-    netgwas.obj <- cbind(netgwas.obj, cross.obj$geno[[i]]$data)
-  }
+  
+  if(nchr == 1) return(netgwas.obj) else{ 
+      for(i in 2: nchr ) {
+      netgwas.obj <- cbind(netgwas.obj, cross.obj$geno[[i]]$data)
+      }
   return(netgwas.obj)
+  }
+  
   #pos.map$geno[[i]]$map
 }
\ No newline at end of file
